def ConvertHexadecimalToOctal(hexadecimal: str) -> int:
    """Convert a hexadecimal number to an octal number."""
    hexadecimal = hexadecimal.upper()
    decimal = 0
    for i in range(len(hexadecimal)):
        decimal = decimal * 16 + int(hexadecimal[i], 16)
    octal = ""
    while decimal != 0:
        octal = str(decimal % 8) + octal
        decimal = decimal // 8
    if octal == "":
        octal = "0"
    return int(octal)



from .add_two_numbers import AddTwoNumbers
from .convert_binary_to_decimal import ConvertBinaryToDecimal
from .convert_binary_to_hexadecimal import ConvertBinaryToHexadecimal
from .convert_binary_to_octal import ConvertBinaryToOctal
from .convert_celsius_to_fahrenheit import ConvertCelsiusToFahrenheit
from .convert_centimeters_to_feet import ConvertCentimetersToFeet
from .convert_centimeters_to_inches import ConvertCentimetersToInches
from .convert_days_to_hours import ConvertDaysToHours
from .convert_days_to_minutes import ConvertDaysToMinutes
from .convert_days_to_seconds import ConvertDaysToSeconds
from .convert_decimal_to_binary import ConvertDecimalToBinary
from .convert_decimal_to_hexadecimal import ConvertDecimalToHexadecimal
from .convert_decimal_to_octal import ConvertDecimalToOctal
from .convert_hexadecimal_to_binary import ConvertHexadecimalToBinary
from .convert_hexadecimal_to_decimal import ConvertHexadecimalToDecimal
from .convert_hexadecimal_to_octal import ConvertHexadecimalToOctal
from .convert_octal_to_binary import ConvertOctalToBinary
from .convert_octal_to_decimal import ConvertOctalToDecimal
from .convert_octal_to_hexadecimal import ConvertOctalToHexadecimal
from .format_to_camelcase import FormatToCamelCase
from .format_to_constantcase import FormatToConstantCase
from .format_to_dotcase import FormatToDotCase
from .format_to_kebabcase import FormatToKebabCase
from .format_to_pascalcase import FormatToPascalCase
from .format_to_pathcase import FormatToPathCase
from .format_to_snakecase import FormatToSnakeCase
from .format_to_titlecase import FormatToTitleCase
from .substract_two_numbers import SubstractTwoNumbers



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="codinasion-tools",
    version="0.1.0",
    author="Harsh Raj",
    author_email="harshraj8843@gmail.com",
    description="A collection of useful open source tools",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/codinasion/codinasion-tools",
    project_urls={
        "Bug Tracker": "https://github.com/codinasion/codinasion-tools/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.10",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    packages=["codinasion_tools"],
    python_requires=">=3.10",
    install_requires=[],
)



from .convert_octal_to_decimal import ConvertOctalToDecimal
from .convert_decimal_to_binary import ConvertDecimalToBinary


def ConvertOctalToBinary(octal_num: int) -> str:
    """Convert an octal number to a binary number."""
    if octal_num == 0:
        return "0"
    return ConvertDecimalToBinary(ConvertOctalToDecimal(octal_num))



def ConvertDecimalToHexadecimal(decimal_number: int) -> str:
    """Convert a decimal number to a hexadecimal number."""
    hexadecimal_number = ""
    while decimal_number > 0:
        remainder = decimal_number % 16
        if remainder < 10:
            hexadecimal_number = str(remainder) + hexadecimal_number
        else:
            hexadecimal_number = chr(remainder + 55) + hexadecimal_number
        decimal_number = decimal_number // 16
    if hexadecimal_number == "":
        hexadecimal_number = "0"
    return hexadecimal_number
